@@ -16,10 +16,13 @@ import json
 from typing import TYPE_CHECKING, Any, Literal, overload
 
 import pact.v3.ffi
+from pact.v3.match.matcher import IntegrationJSONEncoder
 
 if TYPE_CHECKING:
     from pathlib import Path
 
+    from pact.v3.match import Matcher
+
     try:
         from typing import Self
     except ImportError:
@@ -245,7 +248,7 @@ class Interaction(abc.ABC):
 
     def with_body(
         self,
-        body: str | None = None,
+        body: str | dict[str, Any] | Matcher[Any] | None = None,
         content_type: str | None = None,
         part: Literal["Request", "Response"] | None = None,
     ) -> Self:
@@ -266,11 +269,16 @@ class Interaction(abc.ABC):
                 If `None`, then the function intelligently determines whether
                 the body should be added to the request or the response.
         """
+        if body and isinstance(body, str):
+            body_str = body
+        else:
+            body_str = json.dumps(body, cls=IntegrationJSONEncoder)
+
         pact.v3.ffi.with_body(
             self._handle,
             self._parse_interaction_part(part),
             content_type,
-            body,
+            body_str,
         )
         return self
 
