@@ -4,13 +4,18 @@ HTTP interaction.
 
 from __future__ import annotations
 
+import json
 from collections import defaultdict
-from typing import TYPE_CHECKING, Iterable, Literal
+from typing import TYPE_CHECKING, Any, Literal
 
 import pact.v3.ffi
 from pact.v3.interaction._base import Interaction
+from pact.v3.match import Matcher
+from pact.v3.match.matcher import IntegrationJSONEncoder
 
 if TYPE_CHECKING:
+    from collections.abc import Iterable
+
     try:
         from typing import Self
     except ImportError:
@@ -94,7 +99,7 @@ class HttpInteraction(Interaction):
         """
         return self.__interaction_part
 
-    def with_request(self, method: str, path: str) -> Self:
+    def with_request(self, method: str, path: str | Matcher[Any]) -> Self:
         """
         Set the request.
 
@@ -106,13 +111,17 @@ class HttpInteraction(Interaction):
             path:
                 Path for the request.
         """
-        pact.v3.ffi.with_request(self._handle, method, path)
+        if isinstance(path, Matcher):
+            path_str = json.dumps(path, cls=IntegrationJSONEncoder)
+        else:
+            path_str = path
+        pact.v3.ffi.with_request(self._handle, method, path_str)
         return self
 
     def with_header(
         self,
         name: str,
-        value: str,
+        value: str | dict[str, str] | Matcher[Any],
         part: Literal["Request", "Response"] | None = None,
     ) -> Self:
         r"""
@@ -208,12 +217,16 @@ class HttpInteraction(Interaction):
         name_lower = name.lower()
         index = self._request_indices[(interaction_part, name_lower)]
         self._request_indices[(interaction_part, name_lower)] += 1
+        if not isinstance(value, str):
+            value_str: str = json.dumps(value, cls=IntegrationJSONEncoder)
+        else:
+            value_str = value
         pact.v3.ffi.with_header_v2(
             self._handle,
             interaction_part,
             name,
             index,
-            value,
+            value_str,
         )
         return self
 
@@ -342,7 +355,11 @@ class HttpInteraction(Interaction):
             self.set_header(name, value, part)
         return self
 
-    def with_query_parameter(self, name: str, value: str) -> Self:
+    def with_query_parameter(
+        self,
+        name: str,
+        value: str | dict[str, str] | Matcher[Any],
+    ) -> Self:
         r"""
         Add a query to the request.
 
@@ -374,7 +391,7 @@ class HttpInteraction(Interaction):
         ```
 
         It is also possible to have a more complicated Regex pattern for the
-        paramater. For example, a pattern for an `version` parameter might be
+        parameter. For example, a pattern for an `version` parameter might be
         specified as:
 
         ```python
@@ -402,17 +419,21 @@ class HttpInteraction(Interaction):
         """
         index = self._parameter_indices[name]
         self._parameter_indices[name] += 1
+        if not isinstance(value, str):
+            value_str: str = json.dumps(value, cls=IntegrationJSONEncoder)
+        else:
+            value_str = value
         pact.v3.ffi.with_query_parameter_v2(
             self._handle,
             name,
             index,
-            value,
+            value_str,
         )
         return self
 
     def with_query_parameters(
         self,
-        parameters: dict[str, str] | Iterable[tuple[str, str]],
+        parameters: dict[str, Any] | Iterable[tuple[str, Any]],
     ) -> Self:
         """
         Add multiple query parameters to the request.
